Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3494)

Unified Diff: cc/tiles/raster_tile_priority_queue_all.cc

Issue 2404423002: cc: Make pending visible rect active tree tiles be in the NOW bin. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/tiles/picture_layer_tiling.cc ('k') | cc/tiles/tile_manager_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/tiles/raster_tile_priority_queue_all.cc
diff --git a/cc/tiles/raster_tile_priority_queue_all.cc b/cc/tiles/raster_tile_priority_queue_all.cc
index a197b1284380dc9f7c96dbae2bb65543cc550334..0d54a592607ee0558de53349c83fdde3c0aaf86a 100644
--- a/cc/tiles/raster_tile_priority_queue_all.cc
+++ b/cc/tiles/raster_tile_priority_queue_all.cc
@@ -145,14 +145,16 @@ RasterTilePriorityQueueAll::GetNextQueues() const {
switch (tree_priority_) {
case SMOOTHNESS_TAKES_PRIORITY: {
- // If we're down to eventually bin tiles on the active tree and there
- // is a pending tree, process the entire pending tree to allow tiles
- // required for activation to be initialized when memory policy only
- // allows prepaint. The eventually bin tiles on the active tree are
- // lowest priority since that work is likely to be thrown away when
- // we activate.
- if (active_priority.priority_bin == TilePriority::EVENTUALLY)
+ // If we're down to soon bin tiles on the active tree and there
+ // is a pending tree, process the now tiles in the pending tree to allow
+ // tiles required for activation to be initialized when memory policy only
+ // allows prepaint. The soon/eventually bin tiles on the active tree are
+ // lowest priority since that work is likely to be thrown away when we
+ // activate.
+ if (active_priority.priority_bin >= TilePriority::SOON &&
+ pending_priority.priority_bin == TilePriority::NOW) {
return pending_queues_;
+ }
return active_queues_;
}
case NEW_CONTENT_TAKES_PRIORITY: {
« no previous file with comments | « cc/tiles/picture_layer_tiling.cc ('k') | cc/tiles/tile_manager_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698